@@ -1,3 +1,10 @@
+# RecPack, An Experimentation Toolkit for Top-N Recommendation
+# Copyright (C) 2020  Froomle N.V.
+# License: GNU AGPLv3 - https://gitlab.com/recpack-maintainers/recpack/-/blob/master/LICENSE
+# Author:
+#   Lien Michiels
+#   Robin Verachtert
+
 """Module responsible for the DummyDataset dataset."""
 
 import numpy as np
@@ -19,8 +26,7 @@ class DummyDataset(Dataset):
     :param path: The path to the data directory. UNUSED because dataset is generated and not read from file.
         Defaults to `data`
     :type path: str, optional
-    :param filename: Name of the file, if no name is provided the dataset default will be used if known.
-        UNUSED because dataset is generated and not read from file.
+    :param filename: UNUSED because dataset is generated and not read from file.
     :type filename: str, optional
     :param use_default_filters: Should a default set of filters be initialised? Defaults to True
     :type use_default_filters: bool, optional
